/** Debug *********************************************************************/
/*#footer, nav { border: 1px solid red; }*/
/*.bright, .bleft { border: 1px solid red; }*/
/*.side-right, .side-left { background-color: #888; }*/

/** Fonts *********************************************************************/
/* A font by Jos Buivenga (exljbris) -> http://www.exljbris.nl */
@font-face {
  font-family: "Calluna-Exljbris";
  src: url(fonts/Calluna-Regular.otf) format("opentype");
}

#header h1, #header .subtitle, nav li a, footer, footer p, h2, h3, #articulos h1
{ font-family: Calluna-Exljbris, Georgia, "Times New Roman", Times, serif; }

/** General *******************************************************************/
html, body { color: #111111; background: url(../img/back.gif) repeat; }
.centered { margin: 0px auto; text-align: center; }

/** Container *****************************************************************/

/** Header ********************************************************************/
#header { height: 120px; margin-top: 30px; }
#header h1 { font-weight: normal; color: #111; text-shadow: 0px 1px 1px white; font-size: 50px;
		     margin-bottom: 10px; text-align: center; }
#header .subtitle { color: #666; text-align: center; margin: 0; font-size: 18px; font-weight: bold; }

/** Nav ***********************************************************************/
nav { border: 1px solid #e5e5e5; padding: 10px 0 1px 0; background-color: #fff; border-radius: 6px; margin-top: 10px; }
nav li { display: inline; padding: 2px 5px 10x 5px;  }
nav li a { padding: 0 5px 0 5px; font-size: 16px; }
nav li:after { content: "—" ; }
nav li.last:after { content: ""; }

/** Content *******************************************************************/
h2 { font-size: 1.5em;  }
.content { border: 1px solid #e5e5e5; margin: 30px 0 30px 0; padding: 10px;
		   background-color: #fff; border-radius: 6px;}

/** Content *******************************************************************/
.notification { margin: 20px 0 0 0; }
.notification .alert { margin-bottom: 0px; }

/** Footer ********************************************************************/
footer { margin-top: 40px; }
footer, footer p { text-align: center; margin: 0px auto; font-size: 16px; color: #666; }

/** Media Queries *************************************************************/
/* Tablets */
@media only screen and (min-width: 738px) and (max-width: 960px){ 
  #companyVideo-97 { width: 518px; height: 237px; }
}

/* Mobile wide */
@media only screen and (min-width: 480px) and (max-width: 737px){ 
  #companyVideo-97 { width: 418px; height: 137px; }
}

/* Mobile narrow*/
@media only screen and (max-width: 479px){
  #companyVideo-97 { width: 218px; height: 137px; }
}


/* Flatpages */
#articulos h1 { margin: 5px 0 0 25px; color: #333; font-size: 20px; }
#articulos p { margin: 5px 20px 5px 20px; }

/* Foro */
.forum-top { margin: 0 0 15px 0; text-align: right; }
.forum-top li { display: inline; }
table p { margin-left: 0; }
.forum-title { font-size: 18px; }
.forum h3 { font-family: "Helvetica Neue", Helvetica, Arial, sans-serif; line-height: 20px; color: #08C;  } 
.forum-actions { text-align: right; margin: 0 0 20px 0; }
textarea#id_body { width: 90%; }
input#id_subject { width: 90%; }
textarea#id_message { width: 90%; }

/* Widgets */
article.portada h2 { display: inline; }

/* Auth */
.errorlist { color: #B94A48; background-color: #F2DEDE; border-color: #EED3D7; padding: 8px 35px 8px 14px; margin-bottom: 20px;
			 text-shadow: 0 1px 0 rgba(255, 255, 255, 0.5); border: 1px solid #FBEED5; -webkit-border-radius: 4px;
			 -moz-border-radius: 4px; border-radius: 4px; text-align: center; margin: 0px auto; }
.errorlist li { list-style: none; }
