{% extends "site_base.html" %}

{% block metas %}
    <title>{{ myflatpage.title }} &#8212; {{ settings.SITE_TITLE }}</title>
    <meta name="description" content="{{ myflatpage.text|striptags|truncatewords:50 }}" />
{% endblock %}

{% block breadcrumbs %}
{% endblock %}

{% block content %}
<section id="articulos">
    <h2>{{ myflatpage.title }}</h2>
	{{ myflatpage.text|safe }}

</section>

{% endblock %}

